@@ -2,7 +2,7 @@ package Mail::DMARC;
 use strict;
 use warnings;
 
-our $VERSION = '1.20200214';
+our $VERSION = '1.20210220';
 
 use Carp;
 our $psl_loads = 0;
@@ -254,7 +254,7 @@ sub save_aggregate {
         $agg->metadata->$f( $self->config->{organization}{$f} );
     };
 
-    my ( $begin, $end ) = $self->get_report_window( $self->result->published->ri, time() );
+    my ( $begin, $end ) = $self->get_report_window( $self->result->published->ri, $self->time );
 
     $agg->metadata->begin( $begin );
     $agg->metadata->end( $end );
@@ -309,7 +309,7 @@ Mail::DMARC - Perl implementation of DMARC
 
 =head1 VERSION
 
-version 1.20200214
+version 1.20210220
 
 =head1 SYNOPSIS
 
@@ -655,7 +655,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Matt Simerson.
+This software is copyright (c) 2021 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
